'\"
'\" Copyright (c) 1999 Neil McKay
'\"
'\" See the file "license.terms" for information on usage and redistribution
'\" of this file, and for a DISCLAIMER OF ALL WARRANTIES.
'\" 
'\" RCS: @(#) $Header: /home/neil/src/tcl/nntp/doc/RCS/intrnglist.n,v 1.1 1999/10/25 01:37:06 neil Exp $
'\" 
.so man.macros
.TH "Intrnglist" n 1.0 Tcl "Tcl Integer Set Extension"
.BS
'\" Note:  do not modify the .SH NAME line immediately below!
.SH NAME
Intrnglist \- Sets of integers represented as lists of ranges.
.SH SYNOPSIS
\fBpackage require intrnglist\fP
.sp
\fB::intrnglist::normalize \fIlist\fR
.sp
\fB::intrnglist::combine \fIlist1\fR ?\fIlist2 list3 ...\fR?
.sp
\fB::intrnglist::contains \fIlist num\fR
.sp
\fB::intrnglist::complement \fIlist min max\fR
.sp
\fB::intrnglist::extent \fIlist\fR
.sp
\fB::intrnglist::remove \fIlist1\fR ?\fIlist2 list3 ...\fR?
.sp
\fB::intrnglist::numElements \fIlist\fR
.BE

.SH DESCRIPTION
.PP
The \fBintrnglist\fR package provides operations on sets of
integers, represented as lists of integer ranges. The sets
themselves are represented as Tcl lists, where each list element
is either an integer or a list containing two integers; a single
integer indicates that the integer is an element of the set,
while a pair of integers indicates that all integers between
(and including) the two integers are elements of the set.
.PP
.SH COMMANDS
.TP
\fB::intrnglist::normalize \fIlist\fR
The \fB::intrnglist::normalize\fR command puts the set represented
by \fIlist\fR into simplest form; it returns the simplified list.
By ``simplest form'' we mean, roughly, that the list is the shortest
one that represents the same set as the input list. It will, for instance,
combine overlapping and/or adjacent ranges into a single range.
.TP
\fB::intrnglist::combine \fIlist1\fR ?\fIlist2 list3 ...\fR?
\fB::intrnglist::combine\fR performs a set union of all its arguments.
The function returns the union, in normalized form.
.TP
\fB::intrnglist::contains \fIlist num\fR
The function \fB::intrnglist::contains\fR returns 1 if \fInum\fR is
an element of the set represented by \fIlist\fR, 0 otherwise.
.TP
\fB::intrnglist::complement \fIlist min max\fR
\fB::intrnglist::complement\fR returns the complement of the set
represented by \fIlist\fR, relative to the interval [\fImin\fR,\fImax\fR],
i.e. it returns a set which contains all elements of the
interval  [\fImin\fR,\fImax\fR] that are \fInot\fR in the set
represented by \fIlist\fR.
.TP
\fB::intrnglist::extent \fIlist\fR
The \fB::intrnglist::extent\fR function returns a list containing two numbers:
the smallest and largest numbers in the set represented by \fIlist\fR.
If \fIlist\fR is the empty set, then it returns an empty list.
.TP
\fB::intrnglist::remove \fIlist1\fR ?\fIlist2 list3 ...\fR?
\fB::intrnglist::remove\fR starts with \fIlist1\fR, and removes
all elements of the sets represented by \fIlist2\fR, \fIlist3\fR, etc.
In other words, it performs set subtraction.
.TP
\fB::intrnglist::numElements \fIlist\fR
\fB::intrnglist::numElements\fR returns the number of elements
in the set represented by \fIlist\fR, i.e. the cardinality
of the set.
.SH EXAMPLE
.DS
# Define some sets.

set s1 {{0 4} 7 {9 12}}
set s2 {5 6 7}

# Normalize set s2; this should give {{5 7}}

set ns2 [intrnglist::normalize $s2]

# Perform a union of s1 and s2; this should be {{0 7} {9 12}}

set s1Us2 [intrnglist::combine $s1 $s2]

# See what sets contain the number 5.

if {[intrnglist::contains $s1 5]} {
    puts "Set s1 contains the number 5"
}

if {[intrnglist::contains $s2 5]} {
    puts "Set s2 contains the number 5"
}

if {[intrnglist::contains $s1Us2 5]} {
    puts "Set s1Us2 contains the number 5"
}
.DE
.SH "SEE ALSO"
newsrc(n)
.SH KEYWORDS
integer set, integer range

