'\"
'\" Copyright (c) 1999 Neil McKay
'\"
'\" See the file "license.terms" for information on usage and redistribution
'\" of this file, and for a DISCLAIMER OF ALL WARRANTIES.
'\" 
'\" RCS: @(#) $Header: /home/neil/src/tcl/nntp/doc/RCS/newsrc.n,v 1.1 1999/10/24 21:55:11 neil Exp $
'\" 
.so man.macros
.TH "Newsrc" n 8.0 Tcl "Tcl Newsrc File Manipulation Extension"
.BS
'\" Note:  do not modify the .SH NAME line immediately below!
.SH NAME
Newsrc \- code for manipulating .newsrc files.
.SH SYNOPSIS
\fBpackage require newsrc\fP
.sp
\fB::newsrc::readFile \fIfileHandle\fR
.sp
\fB::newsrc::writeFile \fIfileHandle info\fR
.BE

.SH DESCRIPTION
.PP
The \fBnewsrc\fR package provides routines for reading and writing
``.newsrc'' files.
.PP
.SH COMMANDS
.TP
\fB::nntp::readFile \fIfileHandle\fR
The \fB::nntp::readFile\fR command reads data in the ``.newsrc''
file format from \fIfileHandle\fR. The file must contain one
line of text for each newsgroup. (Blank lines are ignored.)
The lines of text consist of a newsgroup name, followed by a
colon ``:'' for currently-subscribed newsgroups, or an exclamation
point ``!'' for newsgroups that were subscribed to in the past,
but are not currently read. This character should be followed
by (optional) whitespace and a comma-separated list of article
number ranges. Each range may be either a single non-negative integer
or a pair of non-negative integers separated by a ``-''.
The function returns a list consisting of alternating newsgroup/data
pairs, where the data is a two element list: a Boolean indicating
whether the group is currently subscribed to, and a Tcl list of
integer ranges of article numbers. The elements of the Tcl list of
article ranges may be either single integers, or a list containing
two integers.
.TP
\fB::nntp::writeFile \fIfileHandle info\fR
The \fB::nntp::writeFile\fR command writes data in the ``.newsrc''
file format to \fIfileHandle\fR. \fIinfo\fR must be in the format
returned by the \fB::nntp::readFile\fR command.
.SH EXAMPLE
.DS
# See if the user subscribes to comp.lang.tcl; if he
# doesn't, sign him up.

set inFile [open ".newsrc" "r"]
set newsrcInfo [newsrc::readFile $inFile]
close $inFile

array set subscribeArray $newsrcInfo
if {![info exists subscribeArray(comp.lang.tcl)]} {
    puts stderr "You really should read comp.lang.tcl!"
    set subscribeArray(comp.lang.tcl) [list 1 {0}]
    set outFile [open ".newsrc" "w"]
    newsrc::writeFile $outFile [array get subscribeArray]
    close $outFile
} elseif {[lindex $subscribeArray(comp.lang.tcl) 0] == 0} {
    puts stderr "I'm re-subscribing you to comp.lang.tcl!"
    set subscribeArray(comp.lang.tcl) \\
		[list 1 [lindex $subscribeArray(comp.lang.tcl) 1]]
    set outFile [open ".newsrc" "w"]
    newsrc::writeFile $outFile [array get subscribeArray]
    close $outFile
}
.DE
.SH "SEE ALSO"
nntp(n), intrnglist(n)
.SH KEYWORDS
news client, newsrc file

