'\"
'\" Copyright (c) 1999 Neil McKay
'\"
'\" See the file "license.terms" for information on usage and redistribution
'\" of this file, and for a DISCLAIMER OF ALL WARRANTIES.
'\" 
'\" RCS: @(#) $Header: /home/neil/src/tcl/nntp/doc/RCS/nntp.n,v 1.1 1999/10/24 21:12:10 neil Exp $
'\" 
.so man.macros
.TH "Nttp" n 8.0 Tcl "Tcl NNTP Extension"
.BS
'\" Note:  do not modify the .SH NAME line immediately below!
.SH NAME
Nntp \- Client-side implementation of the NNTP protocol.
.SH SYNOPSIS
\fBpackage require nntp\fP
.sp
\fB::nntp::openConnection \fIhostName\fR ?\fIoptions\fR?
.sp
\fB::nntp::closeConnection \fIconnectionHandle\fR
.sp
\fB::nntp::responseCode \fImsg\fR
.sp
\fB::nntp::postingAllowed \fIconnectionHandle\fR
.sp
\fB::nntp::setResponseHandler \fIconnectionHandle handlerProc\fR
.sp
\fB::nntp::getResponseHandler \fIconnectionHandle\fR
.sp
\fB::nntp::getGroupList \fIconnectionHandle\fR
.sp
\fB::nntp::getNewGroups \fIconnectionHandle datime ?options?\fR
.sp
\fB::nntp::setGroup \fIconnectionHandle groupName\fR
.sp
\fB::nntp::getHeader \fIconnectionHandle\fR
.sp
\fB::nntp::getBody \fIconnectionHandle\fR
.sp
\fB::nntp::getNewNews \fIconnectionHandle groupList datime ?options?\fR
.sp
\fB::nntp::setArticlePointer \fIconnectionHandle article\fR
.sp
\fB::nntp::nextArticle \fIconnectionHandle\fR
.sp
\fB::nntp::prevArticle \fIconnectionHandle\fR
.sp
\fB::nntp::post \fIconnectionHandle header body\fR
.sp
\fB::nntp::clientIsSlave \fIconnectionHandle\fR
.sp
\fB::nntp::iHave \fIconnectionHandle messageID header body\fR
.BE

.SH DESCRIPTION
.PP
The \fBnntp\fR package provides the client side of the NNTP
protocol.  The package implements most of the commands described
in RFC 977.
.PP
.SH COMMANDS
.TP
\fB::nntp::openConnection \fIhostName \fP ?\fIoptions\fR?
The \fB::nntp::openConnection\fR command is used to establish a
connection to an NNTP server. If successful, it returns a
connection handle; otherwise, it returns an error message,
and raises an error. Allowed options are:
.RS
.TP
\fB\-port\fP \fIportNo\fP
The TCP port number to connect to. Defaults to 119, the well-known
NNTP port number.
.TP
\fB\-responsehandler\fP \fIhandlerProc\fP
Sets the response handler function. This is a function that will
be executed whenever the NNTP server sends back a status message.
The default is the empty string, which means do nothing with the
status messages. Here is a template for the callback:
.RS
.CS
proc nntpCallback {msg} {
    # Do something with the message...
}
.CE
.RE
.TP
\fB\-user\fP \fIuserName\fP
Use \fIuserName\fR as the user name for authentication. The default
is not to do authentication.
.TP
\fB\-pass\fP \fIpasswd\fP
Use \fIpasswd\fR as the password for authentication. The default
is not to do authentication.
.RE
.TP
\fB::nntp::closeConnection \fIconnectionHandle\fR
The \fB::nntp::closeConnection\fR command breaks the connection with
an NNTP server.
.TP
\fB::nntp::responseCode \fImsg\fR
The \fB::nntp::responseCode\fR command returns the numeric response
code contained in a server status message. The exact meaning of the code
depends on the command executed. (See RFC 977).
.TP
\fB::nntp::postingAllowed \fIconnectionHandle\fR
The \fB::nntp::postingAllowed\fR proc returns 1 if the server represented
by \fIconnectionHandle\fR allows posting, 0 if not.
.TP
\fB::nntp::setResponseHandler \fIconnectionHandle handlerProc\fR
\fB::nntp::setResponseHandler\fR sets the status message handler for
\fIconnectionHandle\fR.
.TP
\fB::nntp::getResponseHandler \fIconnectionHandle\fR
\fB::nntp::getResponseHandler\fR retrieves the status message handler for
\fIconnectionHandle\fR.
.TP
\fB::nntp::getGroupList \fIconnectionHandle\fR
\fB::nntp::getGroupList\fR gets the list of newsgroups handled by the
server represented by \fIconnectionHandle\fR. The value returned is a
Tcl list containing four elements for each newsgroup: the newsgroup
name, the article number of the first article, the article number of the
last article, and the newsgroup's posting status. The posting status
will usually be \fBy\fR, \fBn\fR, or \fBm\fR, for ``yes'', ``no'',
and ``moderated''.
.TP
\fB::nntp::getNewGroups \fIconnectionHandle datime ?options?\fR
The \fB::nntp::getNewGroups\fR command returns a list of newsgroups (in the
same format as the \fBgetGroupList\fR command) that have been updated
since the date and time given by \fIdatime\fR. \fIdatime\fR is a
number, in seconds, in the format returned by the \fBclock scan\fR
and \fBclock seconds\fR commands. Valid options are:
.RS
.TP
\fB\-distlist\fP \fIdistributions\fP
Restricts what ``distributions'' will be reported, i.e. what top-level
newsgroup names (like ``net'', ``alt'', ``comp'', etc.) will be looked at.
Default is to look at all newsgroups.
.TP
\fB\-gmt\fP \fIBoolean\fP
If \fIBoolean\fR is non-zero, use Greenwich mean time (i.e. UTC); otherwise,
use local time. Default is local time.
.RE
.TP
\fB::nntp::setGroup \fIconnectionHandle groupName\fR
\fB::nntp::setGroup\fR sets the newsgroup that server connection
\fIconnectionHandle\fR is currently working with to \fIgroupName\fR.
If successful, it returns a three-element list containing the
newsgroup name and the article numbers of the first and last articles.
If not, it returns an error message, with an error code of 1.
.TP
\fB::nntp::getHeader \fIconnectionHandle\fR
\fB::nntp::getHeader\fR returns the header of the currently-selected
message. If the call fails (for example, if there is no currently-selected
message) then it returns an error message, with an error code of 1.
.TP
\fB::nntp::getBody \fIconnectionHandle\fR
\fB::nntp::getBody\fR returns the body of the currently-selected
message. If the call fails (for example, if there is no currently-selected
message) then it returns an error message, with an error code of 1.
.TP
\fB::nntp::getNewNews \fIconnectionHandle groupList datime ?options?\fR
The \fB::nntp::getNewNews\fR call retrieves the message IDs of all
``new'' messages in the newsgroups given by \fIgroupList\fR. A message
is considered new if it was received by the server after the date and
time given by \fIdatime\fR. \fIdatime\fR is a time in seconds, as used
by the Tcl \fBclock scan\fR and \fBclock seconds\fR commands. Valid
options are:
.RS
.TP
\fB\-grouplist\fP \fIdistributions\fP
Restricts what ``distributions'' will be reported, i.e. what top-level
newsgroup names (like ``net'', ``alt'', ``comp'', etc.) will be looked at.
Default is to look at all newsgroups.
.TP
\fB\-gmt\fP \fIBoolean\fP
If \fIBoolean\fR is non-zero, use Greenwich mean time (i.e. UTC); otherwise,
use local time. Default is local time.
.RE
.TP
\fB::nntp::setArticlePointer \fIconnectionHandle article\fR
The \fB::nntp::setArticlePointer\fR command sets the current article
pointer for the server connection given by \fIconnectionHandle\fR
to \fIarticle\fR, where \fIarticle\fR may be either an article
number or an artice ID. Nothing is returned unless an error occurs,
in which case it returns an error message, and an error code of 1.
.TP
\fB::nntp::nextArticle \fIconnectionHandle\fR
\fB::nntp::nextArticle\fR advances the article pointer associated
with \fIconnectionHandle\fR. It returns either the new article
number or an error.
.TP
\fB::nntp::prevArticle \fIconnectionHandle\fR
\fB::nntp::prevArticle\fR sets the article pointer associated
with \fIconnectionHandle\fR back to the previous article. It returns
either the new article number or an error.
.TP
\fB::nntp::post \fIconnectionHandle header body\fR
The \fB::nntp::post\fR command posts an article to the server.
The \fIheader\fR and \fIbody\fR arguments give the article's
contents; the newsgroup (or newsgroups) that the article will
be posted to are obtained from the header. The function returns
nothing if the article was posted successfully; otherwise
it returns an error.
.TP
\fB::nntp::clientIsSlave \fIconnectionHandle\fR
\fB::nntp::clientIsSlave\fR indicates to the server that the client
is a slave new server, i.e. it is a server requesting a news feed
rather than a normal interactive user. It returns nothing, or an
error message.
.TP
\fB::nntp::iHave \fIconnectionHandle messageID header body\fR
The \fB::nntp::iHave\fR command informs the server that the
client has a message with ID \fImessageID\fR available, if the
server wants it. If the server wants the message, then it is
sent to the server. The function returns nothing, or an error
message.
.SH EXAMPLE
.DS
# Get the first available message in the comp.lang.tcl newsgroup

set NewsServer "news"
set nntpHandle [nntp::openConnection $NewsServer]
nntp::setGroup $nntpHandle "comp.lang.tcl"

set header [nntp::getHeader $nntpHandle]
set body [nntp::getBody $nntpHandle]

puts "$header\\n\\n$body"

nntp::closeConnection $nntpHandle
.DE
.SH "SEE ALSO"
newsrc(n), intrnglist(n)
.SH KEYWORDS
network news, news client

